@@ -132,6 +132,13 @@ pub trait PactPluginRpc {
 
   /// Shutdown a running mock server
   async fn shutdown_mock_server(&self, request: ShutdownMockServerRequest) -> anyhow::Result<ShutdownMockServerResponse>;
+
+  /// Prepare an interaction for verification. This should return any data required to construct any request
+  /// so that it can be amended before the verification is run.
+  async fn prepare_interaction_for_verification(&self, request: VerificationPreparationRequest) -> anyhow::Result<VerificationPreparationResponse>;
+
+  /// Execute the verification for the interaction.
+  async fn verify_interaction(&self, request: VerifyInteractionRequest) -> anyhow::Result<VerifyInteractionResponse>;
 }
 
 /// Running plugin details
@@ -224,6 +231,30 @@ impl PactPluginRpc for PactPlugin {
     let response = client.shutdown_mock_server(tonic::Request::new(request)).await?;
     Ok(response.get_ref().clone())
   }
+
+  async fn prepare_interaction_for_verification(&self, request: VerificationPreparationRequest) -> anyhow::Result<VerificationPreparationResponse> {
+    let channel = self.connect_channel().await?;
+    let auth_str = self.child.plugin_info.server_key.as_str();
+    let token = MetadataValue::from_str(auth_str)?;
+    let mut client = PactPluginClient::with_interceptor(channel, move |mut req: tonic::Request<_>| {
+      req.metadata_mut().insert("authorization", token.clone());
+      Ok(req)
+    });
+    let response = client.prepare_interaction_for_verification(tonic::Request::new(request)).await?;
+    Ok(response.get_ref().clone())
+  }
+
+  async fn verify_interaction(&self, request: VerifyInteractionRequest) -> anyhow::Result<VerifyInteractionResponse> {
+    let channel = self.connect_channel().await?;
+    let auth_str = self.child.plugin_info.server_key.as_str();
+    let token = MetadataValue::from_str(auth_str)?;
+    let mut client = PactPluginClient::with_interceptor(channel, move |mut req: tonic::Request<_>| {
+      req.metadata_mut().insert("authorization", token.clone());
+      Ok(req)
+    });
+    let response = client.verify_interaction(tonic::Request::new(request)).await?;
+    Ok(response.get_ref().clone())
+  }
 }
 
 impl PactPlugin {
